import React, {useMemo} from "react";
import {useTranslation} from "react-i18next";

import {IconBillType, IconMoney, IconStudentEmail, IconStudentId, IconStudentName} from "@/components/icons";
import MoneyFormat from "@/components/money-format.tsx";
import './bill.less'

export const BillDetailItem = (item: { title: React.ReactNode; value: React.ReactNode, icon?: React.ReactNode }) => {
    return <div className={'bill-detail-item'}>
        <div className={'detail-item-title'}>{item.icon} <span className={'item-title'}>{item.title}</span> :</div>
        <div className={'detail-item-value'}>{item.value}</div>
    </div>
}
type BillDetailItemsProps = {
    bill: BillModel;
    studentNumberRender?: React.ReactNode;
}
const BillDetailItems = (prop: BillDetailItemsProps) => {
    const {t} = useTranslation();
    const billType = useMemo(()=>{
        return prop.bill.details[0].bill_type
    },[prop.bill])
    return (<>
        <BillDetailItem icon={<IconBillType/>} title={t('manual.bill_type')} value={billType}/>
        {prop.studentNumberRender?prop.studentNumberRender:<>
            {prop.bill.student_number && prop.bill.student_number != prop.bill.application_number && <BillDetailItem icon={<IconStudentId/>} title={t('manual.student_number')} value={prop.bill.student_number}/> }
            {prop.bill.application_number && <BillDetailItem icon={<IconStudentId/>} title={t('base.bill_number')} value={prop.bill.application_number}/> }
        </>}
        <BillDetailItem icon={<IconStudentName/>} title={t('bill.title_student_name')}
                        value={`${prop.bill.student_english_name||'-'}${prop.bill.student_chinese_name?' / '+ prop.bill.student_chinese_name : ''}`}/>
        <BillDetailItem icon={<IconStudentEmail/>} title={'Email'} value={prop.bill.student_email||'-'}/>
        <BillDetailItem icon={<IconMoney/>} title={t('manual.amount')} value={<MoneyFormat money={prop.bill.amount}/>}/>
    </>)
}

export default BillDetailItems;