import React, {CSSProperties, useRef} from "react";
import QRCodeSvg from "qrcode.react";
import {saveAs} from "file-saver"

import BlankQRCode from "@/assets/images/pay/blank-qr-code.png"
import {getAppUrl} from "@/hooks/useAppUrl.ts";

export type BillQrcodeProps = {
    size?: number;
    bill?: BillModel;
    className?: string;
    style?: CSSProperties;
}

// get bill payment url
export function getPayUrl(billId?: string | number,from='qrcode') {
    const rootUrl = getAppUrl();
    return `${rootUrl}/pay?bill=${billId || 0}&from=${from}`
}

const useBillQRCode = () => {
    const qrCodeRef = useRef<HTMLDivElement>(null)
    const QRCode: React.FC<BillQrcodeProps> = (props) => (
        <div style={props.style} className={props.className} ref={qrCodeRef} data-bill-id={props.bill?.id}>
            {props.bill ? <QRCodeSvg size={props.size} value={getPayUrl(props.bill?.id)}/> : <img src={BlankQRCode}/>}
        </div>);

    // download qr code
    const exportQRCode = () => {
        const canvas = qrCodeRef.current?.querySelector('canvas');
        if (!canvas) return;
        const billId = qrCodeRef.current?.getAttribute('data-bill-id') || Date.now().toString();
        saveAs(canvas.toDataURL(), `qrcode-${billId}.png`)
    }
    return {
        QRCode,
        exportQRCode
    }
};
export default useBillQRCode
