import React from "react";

type MoneyFormatProps = {
    money?: number | string | null;
    currency?: string;
}
const AsiaPayCurrencyConfig: {
    [key: string]: string
} = {
    '344': 'HKD',
    '840': 'USD',
    "702": 'SGD',
    "156": 'CNY(RMB)',
    "392": 'JPY',
    "901": 'TWD',
    "036": 'AUD',
    "978": 'EUR',
    "826": 'GBP',
    "124": 'CAD',
    "446": 'MOP',
    "608": 'PHP',
    "764": 'THB',
    "458": 'MYR',
    "360": 'IDR',
    "410": 'KRW',
    "682": 'SAR',
    "554": 'NZD',
    "784": 'AED',
    "096": 'BND',
    "704": 'VND',
    "356": 'INR',
}

function formatMoneyNumber(amount: string | number) {
    if (amount === '0' || amount === '0.00') {
        return '0.00';
    }
    // 将金额转换为字符串，并限制小数点后两位
    let amountStr = Number(amount).toFixed(2);

    // 移除可能的负号
    const isNegative = amountStr[0] === '-';
    if (isNegative) {
        amountStr = amountStr.slice(1);
    }
    // 将金额字符串拆分为整数和小数部分
    const [intPart, decimalPart] = amountStr.split('.');
    // 整数部分每三位添加一个逗号
    const formattedIntPart = intPart.replace(/\B(?=(\d{3})+(?!\d))/g, ',');
    // 返回格式化后的金额
    return (isNegative ? '-' : '') + formattedIntPart + '.' + decimalPart;
}

const formatCurrency = (currency = 'HKD') => {
    if (currency && /^\d{3}$/.test(currency)) {
        return AsiaPayCurrencyConfig[currency] || currency || 'HKD';
    }
    return currency || 'HKD';
}

const MoneyFormat: React.FC<MoneyFormatProps> = ({money, currency = 'HKD'}) => {
    // 将货币数字转换为千分位格式且带2位小数
    return (money || money == 0 || money == '0') ?
        <span className={'money-format'}>{formatCurrency(currency)} {formatMoneyNumber(money)}</span> : 'N/A';
}
export default MoneyFormat;