import useLocalStorage from "@/hooks/useLocalStorage";
import React, {createContext, useEffect} from "react";
import {useTranslation} from "react-i18next";

const config: ConfigProps = {
    fontFamily: `'Public Sans', sans-serif`,
    i18n: 'en-US',
    appName: "Payment System",
};

const initialState: CustomizationProps = {
    ...config,
    onChangeContainer: () => {
    },
    onChangeLocalization: (_: I18n) => {
    },
    onChangeFontFamily: (_: string) => {
    }
};

// ==============================|| CONFIG CONTEXT & PROVIDER ||============================== //

const ConfigContext = createContext(initialState);
export const ConfigProvider = ({children}: { children: React.ReactNode }) => {
    const [config, setConfig] = useLocalStorage('app-payment-config', initialState);
    const {i18n} = useTranslation()
    // 改变语言
    const onChangeLocalization = (lang: I18n) => {
        setConfig({
            ...config,
            i18n: lang
        });
    };
    // 更改字体
    const onChangeFontFamily = (fontFamily: string) => {
        setConfig({...config, fontFamily})
    }
    useEffect(() => {
        // init localization use LocalStorage
        if (config.i18n) {
            i18n.changeLanguage(config.i18n).then(() => console.log('init localization use', config.i18n))
        }
    }, [])

    return (
        <ConfigContext.Provider value={{
            ...config, onChangeFontFamily, onChangeLocalization
        }}>{children}</ConfigContext.Provider>
    )
}
export default ConfigContext