import {Button, Dropdown, Space} from "@douyinfe/semi-ui";
import {IconLanguage} from "@douyinfe/semi-icons";

import useConfig from "@/hooks/useConfig.ts";
import {useTranslation} from "react-i18next";

const LocaleList: {
    key: I18n,
    text: string,
}[] = [
    {key: 'zh-CN', text: '简体中文'},
    {key: 'zh-HK', text: '繁體中文'},
    {key: 'en-US', text: 'English'}
]
export const I18nSwitcher = () => {
    const {i18n} = useTranslation();
    const {onChangeLocalization, i18n: locale} = useConfig()

    const changeLocale = (key: I18n) => {
        i18n.changeLanguage(key).then(() => {
            onChangeLocalization(key)
        })
    }

    return <Dropdown
        clickToHide
        render={
            <Dropdown.Menu>
                {LocaleList.map((it) => (
                    <Dropdown.Item
                        active={locale == it.key} key={it.key}
                        onClick={() => changeLocale(it.key)}
                        icon={<span>{it.key.split('-')[1].toUpperCase()}</span>}
                    >{it.text}</Dropdown.Item>
                ))}
            </Dropdown.Menu>
        }
    >
        <Button theme="borderless" style={{marginRight:3}}>
            <Space align={'center'} spacing={2} style={{transform:'translateY(3px)'}}>
                <IconLanguage style={{ color: '#fff' }} />
            {/*     {LocaleList.find(s => s.key == locale)?.text}*/}
            </Space>
        </Button>
    </Dropdown>
}