import {Card} from "@/components/card";
import {useSetState} from "ahooks";
import {Button, Select, Space, Toast} from "@douyinfe/semi-ui";
import {useTranslation} from "react-i18next";
import {useEffect, useMemo} from "react";
import {getPermissionList, savePermissionList} from "@/service/api/user.ts";
import {useRemoteUserList} from "@/hooks/useRemoteUserList.ts";

const DEFAULT_ROLES = [
	'root', 'ro', 'fo'
]

const Permission = () => {
	const {t} = useTranslation()
	const usernameList = useRemoteUserList();
	const [state, setState] = useSetState<{
		list: PermissionUserList[];
		loading?: boolean;
	}>({
		list: []
	})
	const onUsernameChange = (role_name: string, username_list: string[]) => {
		const index = state.list.findIndex(it => it.role_name == role_name)
		if (index != -1) {
			state.list[index] = {
				role_name, username_list
			};
			setState({
				list: state.list
			})
		}
	}
	const saveRoles = () => {
		setState({
			loading: true
		})
		savePermissionList(state.list).then(() => {
			Toast.success({content: `Save Success`, duration: 3,})
		}).catch(e => {
			Toast.error({
				content: `Save Error:${e.message}`,
				duration: 3,
			})
		}).finally(() => {
			setState({loading: false})
		})
	}
	const loadAllPermission = () => {
		setState({
			loading: true
		})
		getPermissionList().then(list => {
			const roles: {
				[key: string]: string[]
			} = {}
			// array to object
			list.forEach(it => {
				roles[it.role_name] = it.username_list
			})
			const permissionList: PermissionUserList[] = [];
			DEFAULT_ROLES.forEach(role_name => {
				permissionList.push({
					role_name, username_list: roles[role_name]
				})
			})
			setState({list: permissionList})
		}).finally(() => {
			setState({loading: false})
		})
	}
	useEffect(loadAllPermission, [])
	const optionList = useMemo(() => (usernameList.map(name => ({label: name, value: name}))), [usernameList])

	return (<Card style={{marginBottom: 20}}>
		{state.list.map(it => (<div key={it.role_name} style={{marginBottom: 20}}>
			<div className="permission-title" style={{marginBottom: 5}}>{it.role_name.toUpperCase()}</div>
			<Select
				style={{width: '100%', backgroundColor: 'var(--semi-color-fill-0)'}}
				filter
				multiple
				size={'large'}
				defaultValue={it.username_list}
				optionList={optionList}
				defaultActiveFirstOption
				allowCreate={true}
				placeholder={t('base.please_select')}
				onChange={(users) => onUsernameChange(it.role_name, users as string[])}
			/>
		</div>))}
		<Space>
			<Button
				loading={state.loading} onClick={saveRoles}
				theme={'solid'}>{state.loading ? 'Loading' : t('base.save')}</Button>
			{/*<div>{state.message||''}</div>*/}
		</Space>
	</Card>)
}
export default Permission