import {Button, Col, Form, Modal, Row, Select, Space} from "@douyinfe/semi-ui";
import React from "react";
import {useTranslation} from "react-i18next";
import {useSetState} from "ahooks";
import {useBillTypes} from "@/hooks/useBillTypes.ts";

type BillPaidModalProps = {
	onConfirm: () => void
	onCancel?: () => void
}
export const AddBillModal: React.FC<BillPaidModalProps> = (props) => {
	const {t} = useTranslation()
	const BillTypes = useBillTypes()

	const [state, setState] = useSetState<{
		loading?: boolean;
		open?:boolean
	}>({})


	const onSubmit = (values: BillUpdateParams) => {
		setState({
			loading: true
		})
		console.log(values)
	}
	return (<>
		<Button onClick={()=>setState({open:true})} theme={'solid'}>{t('bill.import_bill')}</Button>
		<Modal
			title={t('bill.import_bill')}
			visible={state.open}
			closeOnEsc={true}
			onCancel={()=>setState({open:false})}
			footer={null}
			width={600}
			okText={t('base.confirm')}
			maskClosable={false}
		>

			<Form<BillUpdateParams> onSubmit={onSubmit} initValues={{
				payment_channel: 'FLYWIRE',
				payment_method: '',
				merchant_ref: '',
				payment_amount: '',
				actual_payment_amount: '',
			}}>
				<Row gutter={20}>
					<Col span={12}>
						<Form.Select
							field={t('manual.bill_type')}
							style={{width: '100%'}}
							placeholder={t('base.please_select')}>
							{
								BillTypes.map((it, idx) => (
									<Select.Option key={idx} value={it.label}>{it.label}</Select.Option>))
							}
						</Form.Select>
					</Col>
					<Col span={12}>
						<Form.Input
							rules={[
								{required: true, message: 'required error'},
							]}
							showClear field="application_number" label={t('bill.bill_number')}
							placeholder={t('base.please_enter')} style={{width: '100%'}}/>
					</Col>
				</Row>
				<Row gutter={20}>
					<Col span={12}>
						<Form.Input
							type={'number'}
							rules={[
								{required: true, message: 'required error'},
							]}
							showClear field="amount" label={t('bill.title_amount')}
							placeholder={t('base.please_enter')} style={{width: '100%'}}/>
					</Col>
					<Col span={12}>
						<Form.Select
							rules={[
								{required: true, message: 'required error'},
							]}
							optionList={[
								{value: 'card', label: 'Card(VISA,MasterCard,UnionPay,JCB...)'},
								{value: 'wechat', label: 'Wechat'},
								{value: 'alipay', label: 'Alipay'},
								{value: 'other', label: 'Other'},
							]}
							allowCreate filter showClear field="payment_method" label={t('bill.title_pay_method')}
							placeholder={t('base.please_select')} style={{width: '100%'}}/>
					</Col>
				</Row>
				<Row gutter={20}>
					<Col span={12}>
						<Form.Input
							rules={[
								{required: true, message: 'required error'},
							]}
							showClear field="merchant_ref" label="Merchant Ref"
							placeholder={t('base.please_enter')} style={{width: '100%'}}/>
					</Col>
					<Col span={6}>
						<Form.Input
							rules={[
								{required: true, message: 'required error'},
							]} type={'number'} showClear
							field="payment_amount" label={t('bill.title_pay_amount')}
							placeholder={t('base.please_enter')} style={{width: '100%'}}/>
					</Col>
					<Col span={6}>
						<Form.Input
							type={'number'}
							showClear field="actual_payment_amount" label={t('bill.title_actual_payment_amount')}
							placeholder={t('base.please_enter')} style={{width: '100%'}}/>
					</Col>
				</Row>
				<Row gutter={20}>
					<Col span={24}>
						<Form.TextArea
							rules={[{required: true, message: 'required error'}]}
							showClear field="remark" label={t('bill.title_remark')} placeholder={t('base.please_enter')}
							style={{width: '100%'}}/>
					</Col>
				</Row>
				{/*<p style={{marginTop: 10}}>{t('bill.paid_confirm')}</p>*/}
				<div className={'text-right'} style={{margin: '10px 0 20px'}}>
					<Space spacing={12}>
						<Button onClick={props.onCancel} type={'tertiary'}>{t('base.cancel')}</Button>
						<Button
							loading={state.loading} htmlType={'submit'} theme={'solid'}
							type={'primary'}>{t('base.confirm_paid')}</Button>
					</Space>
				</div>
			</Form>
		</Modal>
	</>)
}