import React from "react";
import {Button, Modal, Popconfirm} from "@douyinfe/semi-ui";
import {useTranslation} from "react-i18next";
import {confirmBillType} from "@/service/api/bill.ts";
import {useSetState} from "ahooks";

type BillTypeConfirmBatchProps = {
	selectKeys: number[];
	data?: RecordList<BillModel>;
	onConfirm: () => void;
}
export const BillTypeConfirmBatch: React.FC<BillTypeConfirmBatchProps> = (props) => {
	const {t} = useTranslation()
	const [state, setState] = useSetState({loading: false})
	const confirm = (confirmedBills: BillConfirmParams[]) => {
		confirmBillType(confirmedBills).then(() => {
			props.onConfirm()
		}).finally(() => {
			setState({loading: false})
		})
	}
	const confirmBillTypeBatch = () => {
		const bills: BillConfirmParams[] = [];
		const arr = props.data?.list.filter(item => props.selectKeys.includes(item.id));
		if(!arr) return;
		for (let i = 0; i < arr.length; i++) {
			const item = arr[i];
			if(item.confirm_status != 'UNCONFIRMED'){
				continue;
			}
			// 判断confirm的总金额是否和实付金额相等
			const total = item.details.reduce((total, item) => {
				return total + Number(item.amount)
			}, 0)
			if(total != item.actual_payment_amount){
				Modal.warning({
					title: 'Warning',
					content: t('bill.confirm_bill_warning_amount_id',{id: item.id})
				})
				return;
			}
			bills.push({
				id: item.id,
				confirm_application_number: String(item.application_number),
				confirm_student_number: item.student_number,
				detail_confirms: item.details.map(d => {
					return {
						bill_type: d.bill_type,
						bill_detail_id: d.id,
						amount: d.amount
					}
				})
			})
		}
		if (bills.length == 0) return;
		confirm(bills)
	}
	return (<>
		{props.selectKeys.length == 0 || !props.data || props.data.list.length == 0 ?
			<Button disabled>{t('bill.confirm_bill_type_batch')}</Button> :
			<Popconfirm
				title={'Warning'}
				content={`${t('base.confirm_next_operation')}?`}
				onConfirm={() => confirmBillTypeBatch()}
			>
				<Button loading={state.loading} theme={'solid'}>{t('bill.confirm_bill_type_batch')}</Button>
			</Popconfirm>}
	</>)
}