import {Button, Form, Space, Toast} from "@douyinfe/semi-ui";
import {useTranslation} from "react-i18next";
import {useRef, useState} from "react";

import {Card} from "@/components/card";
import {useBillTypes} from "@/hooks/useBillTypes.ts";
import {BillDetailItems, useBillQRCode} from "@/components/bill";

import styles from './manual.module.less'
import {createManualBill,} from "@/service/api/bill.ts";
import {useSetState} from "ahooks";
import {BizError} from "@/service/types.ts";
import {IconAlertTriangle} from "@douyinfe/semi-icons";
import dayjs from "dayjs";


export default function Index() {
    const {t} = useTranslation()
    const frm = useRef<Form<ManualCreateBillParam>>(null)
    const [billInfo, setBillInfo] = useState<BillModel>()
    const {exportQRCode, QRCode} = useBillQRCode();
    const [state, setState] = useSetState({
        loading: false,
        errorMessage: ''
    })

    const handleSubmit = (values: ManualCreateBillParam) => {
        setState({loading: true, errorMessage: ''})
        createManualBill(values).then((ret) => {
            console.log(ret)
            frm.current?.formApi.reset();
            Toast.info({
                content: t('manual.success'),
            })
            setBillInfo(ret)
            //getBillDetail(ret.id).then(setBillInfo);
        }).catch((e: BizError) => {
            setState({errorMessage: e.message})
        }).finally(() => {
            setState({loading: false})
        })
    }
    // useEffect(()=>{
    //     getBillDetail(100009).then(setBillInfo);
    // },[])
    const BillTypes = useBillTypes()

    const BillInfo = ({bill}: { bill?: BillModel }) => {
        if (!bill) return null;
        return (<>
            <BillDetailItems bill={bill}/>
            <Button onClick={exportQRCode} style={{marginTop: 20}} theme={'solid'} type={'primary'}>Download QR
                code</Button>
        </>)
    }
    return (<Card>
        <div className={styles.manualPage}>
            <div className={styles.generateForm}>
                <Form<ManualCreateBillParam>
                    layout='horizontal' onValueChange={() => setState({errorMessage: ''})}
                    onSubmit={handleSubmit} ref={frm}>
                    <Form.Select
                        field="bill_type" style={{width: 200}}
                        label={t('manual.bill_type')}
                        placeholder={t('manual.bill_type')}
                        rules={[{required: true, message: t('manual.bill_type_required')}]}
                    >
                        {
                            BillTypes.map((it, idx) => (
                                <Form.Select.Option key={idx} value={it.label}>{it.label}</Form.Select.Option>))
                        }
                    </Form.Select>
                    <Form.Input
                        field='amount' label={t('manual.amount')} style={{minWidth: 200}}
                        placeholder={t('manual.amount')}
                        rules={[
                            {required: true, message: t('manual.amount_required')},
                            {
                                type: 'number',
                                validator: (_, v) => {
                                    console.log(_, v)
                                    return !isNaN(v) && Number(v) > 0;
                                },
                                message: t('manual.amount_gt0')
                            }
                        ]}
                    />
                    <Form.Input
                        field='student_number' label={t('manual.student_number')} style={{minWidth: 200}}
                        placeholder={t('manual.student_number')}
                        rules={[{required: true, message: t('manual.student_number_required')}]}
                    />
                    <div className={styles.generateButtonContainer}>
                        <Space>
                            <Button loading={state.loading} htmlType="submit" theme={'solid'}>{t('manual.btn_generate')}</Button>
                            {state.errorMessage && <div className={'semi-form-field-error-message'}>
                                <IconAlertTriangle/>{state.errorMessage}</div>}
                        </Space>
                    </div>
                </Form>

            </div>
            <Space className={styles.billDetail} align={'start'}>
                <div style={{minWidth: 250}}>
                    <BillInfo bill={billInfo}/>
                </div>
                <div className={styles.billQrCode}>
                    <div className={styles.QRCodeContainer}>
                        <QRCode size={250} className={styles.qrCode} bill={billInfo}/>
                    </div>
                    {billInfo && billInfo.expiration_time && <div
                        className={styles.billExpTime}> {t('manual.exp_time')} {dayjs(billInfo.expiration_time).format('YYYY-MM-DD HH:mm')} </div>}
                </div>
            </Space>
        </div>
    </Card>)
}