import styles from "@/pages/pay/pay.module.less";
import React, {useEffect, useMemo} from "react";
import {useSetState} from "ahooks";
import {getAsiaPayData} from "@/service/api/bill.ts";
import {getAppUrl} from "@/hooks/useAppUrl.ts";
import {useTranslation} from "react-i18next";

export const StartAsiaPay: React.FC<{ bill: BillModel }> = ({bill}) => {
    const appUrl = getAppUrl();
    const {i18n, t} = useTranslation()
    const lang = useMemo(() => {
        return i18n.language === "zh-CN" ? "X" : (
            i18n.language === "zh-HK" ? "C" : "E"
        )
    }, [i18n.language])

    const [state, setState] = useSetState<{
        loading: boolean;
        pay?: AsiaPayModel;
    }>({
        loading: false
    })
    useEffect(() => {
        getAsiaPayData(bill.id).then((pay) => setState({pay})).catch(console.error)
    }, [])

    return (<form name="payFormCard" method="post" action={state.pay?.pay_url || ''}>
        <input type="hidden" name="merchantId" value={state.pay?.merchantId || ''}/>
        <input type="hidden" name="amount" value={state.pay?.payment_amount}/>
        <input type="hidden" name="orderRef" value={state.pay?.merchant_ref}/>
        <input type="hidden" name="currCode" value={state.pay?.currCode || ''}/>
        <input type="hidden" name="mpsMode" value={state.pay?.mpsMode || ''}/>
        <input type="hidden" name="successUrl" value={`${appUrl}/pay/success?from=ASIAPAY&bill=${bill.id}`}/>
        <input type="hidden" name="failUrl" value={`${appUrl}/pay/fail?from=ASIAPAY&bill=${bill.id}`}/>
        <input type="hidden" name="cancelUrl" value={`${appUrl}/pay/cancel?from=ASIAPAY&bill=${bill.id}`}/>
        <input type="hidden" name="payType" value={state.pay?.payType || ''}/>
        <input type="hidden" name="lang" value={lang || ''}/>
        <input type="hidden" name="payMethod" value={state.pay?.payMethod || ''}/>
        <input type="hidden" name="secureHash" value={state.pay?.pay_url || ''}/>
        <input type="hidden" name="customer_account_id" value={bill.student_number || bill.application_number || ''}/>
        <input type="hidden" name="customer_email" value={bill.student_email || ''}/>
        <input type="hidden" name="customer_firstName" value={bill.student_english_name || bill.student_chinese_name}/>
        <button type={"submit"} disabled={state.loading || !state.pay} className={styles.btnConfirm}>
            {t('pay.confirm_pay')}
        </button>
    </form>)
}