import styles from "@/pages/pay/pay.module.less";
import React, {useEffect, useState} from "react";
import {getAppUrl} from "@/hooks/useAppUrl.ts";
import {useTranslation} from "react-i18next";
import {IconLoading} from "@/components/icons";
import {getFlywirePayUrl} from "@/service/api/bill.ts";

type StartFlyWireProps = {
    open?: boolean;
    bill: BillModel
}

export const StartFlyWire: React.FC<StartFlyWireProps> = ({bill, open}) => {
    const callbackUrl = getAppUrl() + "/pay/success?from=FLYWIRE&bill=" + bill.id;
    const {t} = useTranslation()
    const [loading, setLoading] = useState<boolean>(false)
    const [redirectUrl, setRedirectUrl] = useState<string>()
    useEffect(() => {
        if (bill) {
            setLoading(true)
            getFlywirePayUrl(bill.id, callbackUrl, t(`pay.returnBack`)).then(res => {
                setRedirectUrl(res.url)
            }).catch(console.error).finally(() => setLoading(false))
        }
    }, [bill])

    return (<>
        {open ?  (!loading ? <a href={redirectUrl} className={styles.btnConfirm}>
            {t('pay.confirm_pay')}
        </a> : <button className={styles.btnConfirm} style={{fontSize: 26}}><IconLoading/></button>):<></>}
    </>)
}