import {useTranslation} from "react-i18next";
import {useEffect, useState} from "react";
import {useNavigate, useSearchParams} from "react-router-dom";

import styles from './pay.module.less'
import {PayLogo} from "@/pages/pay/component";
import MoneyFormat from "@/components/money-format.tsx";
import {getBillDetail} from "@/service/api/bill.ts";
import {BillStatus} from "@/service/types.ts";
import {StartFlyWire} from "@/pages/pay/component/start-fly-wire.tsx";


const PayIndex = () => {
    const {t} = useTranslation()
    const navigate = useNavigate()
    const [payChannel, setPayChannel] = useState('')
    const [search] = useSearchParams();
    const [bill, setBill] = useState<BillModel>()

    useEffect(() => {
        const billId = search.get('bill')
        if (!billId || !/^\d+$/.test(billId)) {
            navigate(`/pay/error?bill=${billId}`, {replace: true})
            return;
        }

        // const payChannel = search.get('pay_channel') || 'flywire'
        setPayChannel('flywire')
        getBillDetail(Number(billId)).then((bill) => {
            // 判断bill状态
            if (bill.status != BillStatus.PENDING) {
                navigate(`/pay/error?bill=${billId}&status=bill_status_error`, {replace: true})
            }
            setBill(bill)
        }).catch(() => {
            navigate(`/pay/error?bill=${billId}&msg=bill_error`, {replace: true})
        })
    }, [])
    return (<div className={styles.container}>
        <PayLogo/>
        {bill ? <>
            <div className={`${styles.payAmount} text-center`}>
                <div className="total">{t('pay.total_amount')}</div>
                <div className={styles.totalAmount}>
                    <MoneyFormat money={payChannel == 'asia_pay'?(Number(bill.amount) + Number(bill.service_charge)):bill.amount}/>
                </div>
                <div className="space-center align-center">
                    <div>
                        <span>{t('pay.amount')}: </span>
                        <span className={'no-wrap'}><MoneyFormat money={bill.amount}/></span>
                    </div>
                    {payChannel == 'asia_pay' && <div style={{marginLeft: 10}}>
                        <span>AsiaPay{t('pay.charge')}: </span>
                        <span className={'no-wrap'}><MoneyFormat money={bill.service_charge}/></span>
                    </div>}
                </div>
            </div>
            {/*<div className={styles.payChanel}>*/}
            {/*    <RadioGroup style={{width: '100%'}} type={'card'} onChange={(e) => setPayChannel(e.target.value)}*/}
            {/*                value={payChannel}>*/}
            {/*        <Radio value={'asia_pay'} style={{flex: 1}}>*/}
            {/*            <AsiaPayLogo/>*/}
            {/*            <span style={{marginLeft: 5}}>AsiaPay</span>*/}
            {/*        </Radio>*/}
            {/*        <Radio value={'flywire'} style={{flex: 1}}>*/}
            {/*            <FlywireLogo/>*/}
            {/*            <span style={{marginLeft: 5}}>Flywire</span>*/}
            {/*        </Radio>*/}
            {/*    </RadioGroup>*/}
            {/*</div>*/}
            <div className={styles.payDetail}>
                {bill.details.length == 1 ? <div className="pay-item">
                    <div className="title">Payment Type:</div>
                    <div className="value">{bill.details[0].bill_type}</div>
                </div>:bill.details.map((it, idx) => (
                    <div key={idx} className="pay-item">
                        <div className="title">{it.bill_type}:</div>
                        <div className="value"><MoneyFormat money={it.amount}/></div>
                    </div>
                ))}
            </div>
            <div className={styles.billInfo}>
                <div className="pay-item">
                    <span className="title">Bill Number:</span>
                    <span className="value">{bill.application_number || bill.student_number} - {bill.student_english_name} / {bill.student_chinese_name}</span>
                </div>
                <div className="pay-item">
                    <span className="title">Bill ID:</span>
                    <span className="value">{bill.id}</span>
                </div>
            </div>
            <div className={styles.payConfirm}>
                {bill.student_email && <div className="student-email">Your Email: {bill.student_email}</div> }
                <div className="pay-submit">
                    {/*{ payChannel == 'asia_pay' && <StartAsiaPay bill={bill} />}*/}
                    <StartFlyWire bill={bill} open={payChannel == 'flywire'} />
                </div>
            </div>
        </> : <></>}
    </div>);
}
export default PayIndex;