import React from "react";
import {isRouteErrorResponse, useNavigate, useRouteError} from 'react-router-dom';
import {Button, Col, Row, Space, Typography} from "@douyinfe/semi-ui";
import {Box, Stack} from "@mui/system";
import {useTranslation} from "react-i18next";
import styled from "@emotion/styled";

// material-ui
import error500 from "@/assets/images/error/Error500.png";
import error404 from "@/assets/images/error/Error404.png";
import TwoCone from "@/assets/images/error/TwoCone.png";

// ==============================|| ELEMENT ERROR - COMMON ||============================== //
const ErrorContainer = styled.div({
    minHeight: '100vh', display: "flex", alignItems: 'center', justifyContent: 'center', textAlign: 'center'
})
const ErrorBoundary: React.FC<{
    minHeight?: string | number
}> = ({minHeight}) => {
    const error = useRouteError() as Error;
    // const theme = useTheme();
    // const matchDownSM = useMediaQuery(theme.breakpoints.down('sm'));
    let errorMessage = '服务异常,请稍后再试或者联系管理员.'

    const errorConfig: {
        [key: number]: string
    } = {
        401: '您没有权限访问本页面!',
        404: '访问的页面不存在!',
        503: '服务异常请联系管理员!',
    }
    if (isRouteErrorResponse(error)) {
        if (errorConfig[error.status]) {
            errorMessage = `Error ${error.status} - ${errorConfig[error.status]}`;
        }
    }
    const {t} = useTranslation()
    const navigate = useNavigate()
    const handleGoBack = () => {
        navigate(-1)
    }
    return (<ErrorContainer style={{
        ...(minHeight ? {minHeight: minHeight} : {})
    }}>
        <Row>
            <Col xs={24} sm={24} md={12}>
                <Box sx={{width: {xs: 350, sm: 396}}}>
                    <img src={error500} alt="mantis" style={{height: '100%', width: '100%'}}/>
                </Box>
            </Col>
            <Col xs={12}>
                <Stack justifyContent="center" alignItems="center">
                    <Typography.Title>
                        Internal Server Error
                    </Typography.Title>
                    <Typography.Title>
                        {errorMessage}
                    </Typography.Title>
                    {process.env.NODE_ENV == 'development' && <div>
                        <pre style={{
                            font: 'inherit',
                            textAlign: 'left',
                            maxWidth: 700,
                            marginTop: 20,
                            maxHeight: 300,
                            overflow: 'auto'
                        }}>
                            <code style={{
                                wordBreak: 'break-all',
                                font: 'inherit',
                                whiteSpace: 'break-spaces'
                            }}>{error.stack}</code>
                        </pre>
                    </div>}
                    <Stack sx={{mt: 5}} direction={'row'} spacing={2}>
                        <Button onClick={handleGoBack} theme='solid' type='primary'>
                            {t('error.go_back')}
                        </Button>
                        <Button theme='outline'>
                            <Typography.Text link={{href: '/'}}>{t('error.go_home')}</Typography.Text>
                        </Button>
                    </Stack>
                </Stack>
            </Col>
        </Row>
    </ErrorContainer>);
};

export function Error404() {
    const {t} = useTranslation()
    const navigate = useNavigate()
    const handleGoBack = () => {
        navigate(-1)
    }
    return (
        <ErrorContainer>
            <div>
                <div style={{position: 'relative', margin: 'auto'}}>
                    <Box sx={{width: {xs: 250, sm: 490, margin: 'auto'}}}>
                        <img src={error404} alt="mantis" style={{width: '100%', height: '100%'}}/>
                    </Box>
                    <Box sx={{
                        position: 'absolute',
                        top: 60,
                        right: -240,
                        zIndex: -1,
                        width: {xs: 130, sm: 390},
                        height: {xs: 115, sm: 330}
                    }}>
                        <img src={TwoCone} alt="mantis" style={{width: '100%', height: '100%'}}/>
                    </Box>
                </div>
                <div style={{marginTop: 30}}>
                    <Typography.Title>Page Not Found</Typography.Title>
                    <Typography.Text>The page you are looking might never exist!</Typography.Text>
                    <div style={{marginTop: 30}}>
                        <Space spacing={20} style={{marginTop: 20}}>
                            <Button onClick={handleGoBack} theme='solid' type='primary'>
                                {t('error.go_back')}
                            </Button>
                            <Button theme='outline'>
                                <Typography.Text link={{href: '/'}}>{t('error.go_home')}</Typography.Text>
                            </Button>
                        </Space>
                    </div>
                </div>
            </div>
        </ErrorContainer>
    );
}

export default ErrorBoundary;
