import {createBrowserRouter, Navigate, RouteObject, RouterProvider,} from "react-router-dom";
import {Suspense, useMemo,} from "react";
import {useTranslation} from "react-i18next";

import { LocaleProvider } from '@douyinfe/semi-ui';
import zh_CN from '@douyinfe/semi-ui/lib/es/locale/source/zh_CN';
import zh_TW from '@douyinfe/semi-ui/lib/es/locale/source/zh_TW';
import en_US from '@douyinfe/semi-ui/lib/es/locale/source/en_US';

import ErrorBoundary, {Error404} from "./error.tsx";
import DashboardLayout from "@/routes/layout/dashboard-layout.tsx";
import AuthLogin from "@/pages/auth/login.tsx";
import PayIndex from "@/pages/pay/index.tsx";
import PayResult from "@/pages/pay/result.tsx";
import MainLayout from "@/routes/layout/main-layout.tsx";

import Loader from "@/components/loader.tsx";


import ManualIndex from "@/pages/manual/index.tsx";
import BillQuery from "@/pages/bill/query.tsx";
import BillReconciliation from "@/pages/bill/reconciliation.tsx";
import ExternalCreate from "@/pages/bill/external_create.tsx";
import Permission from "@/pages/auth/permission.tsx";


const routes: RouteObject[] = [
    {
        path: '/',
        element: <MainLayout/>,
        errorElement: <ErrorBoundary/>,
        children: [
            {
                path: '/',
                element: <Navigate to={'/login'}/>
            },
            {
                path: 'login',
                element: <AuthLogin type={'login'}/>
            },
            {
                path: 'login/auth',
                element: <AuthLogin type={'auth'}/>
            },
            {
                path: 'pay',
                element: <PayIndex/>
            },
            {
                path: 'pay/:result',
                element: <PayResult/>
            },
            {
                path: 'bill/external_create',
                element: <ExternalCreate/>
            },
        ]
    },
    {
        path: '/dashboard',
        element: <DashboardLayout/>,
        errorElement: <DashboardLayout><ErrorBoundary minHeight={'70vh'}/></DashboardLayout>,
        children: [
            {
                path: '',
                element: <Navigate to={'/dashboard/manual'} replace/>
            },
            {
                path: 'manual',
                element: <ManualIndex/>
            },
            {
                path: 'bill',
                element: <BillQuery/>
            },
            {
                path: 'reconciliation',
                element: <BillReconciliation/>
            },
            {
                path: 'permission',
                element: <Permission/>
            },
        ]
    },
]

const router = createBrowserRouter([
    ...routes,
    {path: '*', element: <Error404/>}
], {basename: import.meta.env.VITE_APP_BASE_NAME})

const AppRouter = () => {
    // change ui locale
    const {i18n} = useTranslation()
    const locale = useMemo(()=>{
        document.body.setAttribute('data-lang', i18n.language)
        if(i18n.language === 'zh-CN') return zh_CN;
        else if(i18n.language === 'zh-TW') return zh_TW;
        return en_US;
    },[i18n.language])

    return (<LocaleProvider locale={locale}>
        <Suspense fallback={<Loader />}>
            <RouterProvider router={router}/>
        </Suspense>
    </LocaleProvider>)
}

export default AppRouter;