import axios from 'axios';
import {stringify} from 'qs'
import {BizError} from './types';
import {getAuthToken} from "@/hooks/useAuth.ts";

const JSON_FORMAT: string = 'application/json';
const REQUEST_TIMEOUT = 300000; // 超时时长5min

const Axios = axios.create({
    baseURL: AppConfig.API_PREFIX || '/api',
    timeout: REQUEST_TIMEOUT,
    headers: {'Content-Type': JSON_FORMAT}
})


// 请求前拦截
Axios.interceptors.request.use(config => {
    const token = getAuthToken();
    if (token) {
        config.headers['Token'] = `${token}`;
    }
    if (config.data && config.data instanceof FormData) {
        config.headers['Content-Type'] = 'multipart/form-data';
    }
    return config
}, err => {
    return Promise.reject(err)
})

export function request<T>(url: string, method: RequestMethod, data: AllType = null, getOriginResult = false) {
    return new Promise<T>((resolve, reject) => {
        Axios.request<APIResponse<T>>({
            url,
            method,
            data,
        }).then(res => {
            if (res.status != 200) {
                reject(new BizError("Service Internal Exception,Please Try Later!", res.status))
                return;
            }
            if (getOriginResult) {
                resolve(res.data as unknown as T)
                return;
            }
            // const
            const {code, message, data,request_id} = res.data
            if (code == 0) {
                resolve(data as unknown as T)
            } else {
                reject(new BizError(message, code,request_id, data as unknown as AllType))
            }
        }).catch(e => {
            reject(new BizError(e.message, 500))
        })
    })
}


export function post<T>(url: string, data: AllType = {}, returnOrigin = false) {
    return request<T>(url, 'post', data, returnOrigin)
}

export function get<T>(url: string, data: AllType = null, returnOrigin = false) {
    if (data) {
        url += (url.indexOf('?') === -1 ? '?' : '&') + stringify(data)
    }
    return request<T>(url, 'get', data, returnOrigin)
}

export function put<T>(url: string, data: AllType = {}) {
    return request<T>(url, 'put', data)
}

export function getFileBlob(url: string) {
    return new Promise<Blob>((resolve, reject) => {
        fetch(url).then(res => res.blob()).then(res => {
            resolve(res)
        }).catch(reject);
    });
}
