
declare type BaseDate = number | Date | string | null;
declare type BillStatus = 'PAID' | 'CANCELLED' | 'PENDING'
declare type ConfirmStatus = 'UNCONFIRMED' | 'CONFIRMED'
declare type SortOrderType = 'ASC'|'DESC' | string;

// 现场支付账单数据
declare type ManualCreateBillParam = {
    bill_type:string;
    amount:decimal;
    student_number:string;
}
declare type BillDetail = {
    id: number;
    bill_type: string;
    amount: decimal;
    confirmed?: ConfirmedBillDetail[];
}

declare type ConfirmedBillDetail = {
    id?: number;
    bill_detail_id: number;
    bill_type: string;
    amount: decimal;
}
/**
 * 账单查询参数
 */
declare type BillQueryParam = {
    page_size:int;
    page_number:int;
    status:string;
    apply_status:string;
    id:string|number;
    merchant_ref:string;
    /**
     * @deprecated
     */
    bill_type:string;
    confirm_bill_type:string;
    student_number:string;
    application_number:string;
    payment_channel:string;
    /**
     * @deprecated
     */
    start_date:string;
    /**
     * @deprecated
     */
    end_date:string;
    start_initiated:string;
    end_initiated:string;
    start_delivered:string;
    end_delivered:string;
    merchant_ref:string;
    /**
     * @deprecated
     */
    department:string;
    confirm_status: ConfirmStatus;
    sort_field:string;
    sort_order:SortOrderType;
}
declare type BillType = {
    type: string;
    description: string;
}
/**
 * 账单模型
 */
declare type BillModel = {
    id: number;
    student_number: string;
    student_number_confirm?: string;
    application_number: null | string;
    confirm_application_number?: null | string;
    student_email: string;
    student_tc_name?: string;
    student_sc_name?: string;
    student_chinese_name: string;
    student_english_name: string;
    programme_chinese_name: string;
    programme_english_name: string;
    attendance_mode: string;
    department_chinese_name: string;
    department_english_name: string;
    intake_year: string;
    intake_semester: string;
    amount: number|string;
    service_charge?: number;
    payment_amount?:  number;
    actual_payment_amount?: null | number;
    payment_method?: null | string;
    currency?: string;
    payment_channel?: null | string ;
    expiration_time?: BaseDate;
    status: string;
    apply_status: string;
    paid_area?: null | string | number;
    paid_at?:BaseDate;
    merchant_ref?: string;
    payment_id?: null | string | number;
    create_at: BaseDate;
    update_at: BaseDate;
    student_first_name: string;
    student_last_name: string;
    remark: string;
    confirm_status: ConfirmStatus;
    details: BillDetail[]
    detail_confirms: ConfirmedBillDetail[] | null
}


declare type AsiaPayModel = {
    merchantId: number;
    amount: string;
    payment_amount: string;
    service_charge: string;
    merchant_ref: string;
    currCode: number;
    mpsMode: string;
    payType: string;
    payMethod: string;
    pay_url: string;
    details: BillDetail[]
}

type ExternalCreateParamsType = {
    details: BillDetail[];
    [key: string]: string | null;
}

type BillUpdateParams = {
    payment_channel: string;
    payment_method: string;
    actual_payment_amount?: number | string;
    remark?: string;
    merchant_ref?: string;
    payment_amount?: number | string;
}

type BillTypeConfirm = {
    bill_type: string;
    amount: number;
}
type BillConfirmParams = {
    id:number;
    confirm_application_number:string;
    confirm_student_number:string;
    detail_confirms:ConfirmedBillDetail[]
}